
' **************************************************************
' *       Scary Prop Dropper - PICAXE-08M Version              *
' *  Program to operate 2 servo motors to drop and retrieve    *
' *   a small "scare" item like a rubber bat or spider         *
' *     (c) By Vern Graner SSE, Texas Information Services     *
' **************************************************************
' * Created: 8/06/09 Paul M. Atkinson                          *
' * Updated: 8/24/09 Vernon Graner v1.0g                       *
' **************************************************************


' ************************
' * Pin Definitions      *
' *************************************************************************
   Symbol SpoolServo =2    ' Continuous Motion Servo - Used to hoist prop
   Symbol DropServo  =4    ' Standard Servo - Used to position spool servo
   Symbol Trigger    =pin1 ' PIR or other trigger input


' ************************
' * Constants            *
' *************************************************************************
                         ' NOTE: values for servos should between 75 - 225
   Symbol Dump     = 205 ' Value to move Position Servo to"dump" position 
   Symbol Retrieve = 115 ' Value to move Position Servo to "hoist" position

   Symbol Hold     = 132 ' Value to cause Winch Servo to stop moving
   Symbol Hoist    = 75	 ' Value to cause Winch Servo to start moving
   
   Symbol False    = 0   ' \ Used for logic comparisons
   Symbol True     = 1   ' /


' ************************
' * Variables            *
' *************************************************************************
   Symbol cntI   =w0      ' Increment Counter, Used in "FOR" loops etc.


' ************************
' * Init Servos          *
' ************************
'    Pause 50 ' used w/Sertxd -so 1st serial output is clean
    servo DropServo, Retrieve ' Set initial servo positions
    servo SpoolServo, Hold


' ************************
' * Program Begin        *
' *************************************************************************
Main:
'    Sertxd ("Waiting for Trigger",13,10)
    WaitForTrigger:
      PAUSE 100       'Cures issue of servo "jitter" during tight loop
      IF Trigger = False then WaitForTrigger


'   Sertxd ("Trigger Detected, begining drop sequence:",13,10)
    GOSUB Drop      ' Go to subroutine that moves servo to "drop" position


'   Sertxd ("Drop Complete. Waiting to retrieve",13,10)
    PAUSE 3000      ' How long we let the prop "dangle" before retrieving it


'   Sertxd ("Wait complete.",13,10)
    GOSUB Retract  ' Got to subroutine that retracts servo


'   Sertxd ("Hoist Complete. Wait a bit..",13,10)
'    Pause 10000    ' wait 10 seconds after deployment to avoid "retriggering"

'   Sertxd ("Wait complete. Next Victim please!",13,10)
    GOTO MAIN       ' Reset complete, go back to begining


' **************************
' * Subroutines            *
' *************************************************************************

Drop:
 ' **************************
 ' * Move Servo             *
 ' **************************
 '  Sertxd (" -Move Position Servo to 'drop' position",13,10)
  Servopos DropServo,Dump
  RETURN

Retract:
 ' **************************
 ' * Move Servo             *
 ' **************************
 '  Sertxd ("-Moving Position Servo to 'Retrieve' position",13,10)
  Servopos DropServo,Retrieve
  PAUSE 500

 '  Sertxd ("-Activating Hoist",13,10)
  Servopos SpoolServo,Hoist

  Pause 12000 ' Adjust for hoist time (i.e. more time for longer string)
  Servopos SpoolServo,Hold

  RETURN
